Mention @some-bodies_name

Not a repo mention @some-bodies_name/some_repository

Not a repo mention @facelessuser/some_repository

No Commit some-bodies_name/some_repository@3f6b07a8eeaa9d606115758d90f55fec565d4e2a

No Issue some-bodies_name/some_repository#33

No Pull request some-bodies_name/some_repository!33

No Commit 3f6b07a8eeaa9d606115758d90f55fec565d4e2a

No Issue #33

No Pull request !33

No Commit MyRepo@3f6b07a8eeaa9d606115758d90f55fec565d4e2a

No Issue MyRepo#33

No Pull MyRepo!33

Mention @some-user

Mention some-bodies_name/some_repository

Mention facelessuser/some_repository

Issue some-user/some-repo#1

Pull request some-user/some-repo!2

Commit some-user/some-repo@3f6b07a8

@username

No issue #33

No pull request !33

No mention @some-bodies_name

No issue some-bodies_name/some_repository#33

No pull request some-bodies_name/some_repository!33

No commit @3f6b07a8eeaa9d606115758d90f55fec565d4e2a

facelessuser/pymdown-extensions#49

facelessuser/pymdown-extensions!87

facelessuser/pymdown-extensions@6a09fde

fake-user/fake-repository#538

fake-user/fake-repository!539

fake-user/fake-repository@594b25d

fake-user/fake-repository#538

fake-user/fake-repository!539

fake-user/fake-repository@594b25d5

fake-user/fake-repository#538

fake-user/fake-repository!539

fake-user/fake-repository#538

fake-user/fake-repository!539

fake-user/fake-repository@594b25d

facelessuser/pymdown-extensions#49

facelessuser/fake-repository#87

facelessuser/fake-repository@594b25d